CCL: ccl_data Struct Reference

CCL

Data Fields
ccl_data Struct Reference

`#include <ccl_core.h>`

## Data Fields
double | growth0
gsl_spline * | chi
gsl_spline * | growth
gsl_spline * | fgrowth
gsl_spline * | E
gsl_spline * | achi
gsl_interp_accel * | accelerator
gsl_interp_accel * | accelerator_achi
gsl_interp_accel * | accelerator_m
gsl_interp_accel * | accelerator_d
gsl_interp_accel * | accelerator_k
gsl_spline * | logsigma
gsl_spline * | dlnsigma_dlogm
gsl_spline * | alphahmf
gsl_spline * | betahmf
gsl_spline * | gammahmf
gsl_spline * | phihmf
gsl_spline * | etahmf
gsl_spline2d * | p_lin
gsl_spline2d * | p_nl
double | k_min

## Detailed Description

Struct containing references to gsl splines for distance and acceleration calculations

## Field Documentation

## ◆ accelerator

gsl_interp_accel* ccl_data::accelerator

## ◆ accelerator_achi

gsl_interp_accel* ccl_data::accelerator_achi

## ◆ accelerator_d

gsl_interp_accel* ccl_data::accelerator_d

## ◆ accelerator_k

gsl_interp_accel* ccl_data::accelerator_k

## ◆ accelerator_m

gsl_interp_accel* ccl_data::accelerator_m

## ◆ achi

gsl_spline* ccl_data::achi

## ◆ alphahmf

gsl_spline* ccl_data::alphahmf

## ◆ betahmf

gsl_spline* ccl_data::betahmf

## ◆ chi

gsl_spline* ccl_data::chi

## ◆ dlnsigma_dlogm

gsl_spline* ccl_data::dlnsigma_dlogm

## ◆ E

gsl_spline* ccl_data::E

## ◆ etahmf

gsl_spline* ccl_data::etahmf

## ◆ fgrowth

gsl_spline* ccl_data::fgrowth

## ◆ gammahmf

gsl_spline* ccl_data::gammahmf

## ◆ growth

gsl_spline* ccl_data::growth

## ◆ growth0

double ccl_data::growth0

## ◆ k_min

double ccl_data::k_min

## ◆ logsigma

gsl_spline* ccl_data::logsigma

## ◆ p_lin

gsl_spline2d* ccl_data::p_lin

## ◆ p_nl

gsl_spline2d* ccl_data::p_nl

## ◆ phihmf

gsl_spline* ccl_data::phihmf

The documentation for this struct was generated from the following file:

- /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_core.h